@@ -16,10 +16,10 @@ require 'rabl/configuration'
 require 'rabl/renderer'
 require 'rabl/cache_engine'
 
-if defined?(Rails)
-  require 'rabl/tracker'  if Rails.version =~ /^[45]/
-  require 'rabl/digestor' if Rails.version =~ /^[45]/
-  require 'rabl/railtie'  if Rails.version =~ /^[345]/
+if defined?(Rails) && Rails.respond_to?(:version)
+  require 'rabl/tracker'  if Rails.version =~ /^[4567]/
+  require 'rabl/digestor' if Rails.version =~ /^[4567]/
+  require 'rabl/railtie'  if Rails.version =~ /^[34567]/
 end
 
 # Rabl.register!
@@ -83,6 +83,6 @@ end
 if defined?(Padrino)
   require 'padrino-core'
   Padrino.after_load { Rabl.register! }
-elsif defined?(Rails) && Rails.version =~ /^2/
+elsif defined?(Rails.version) && Rails.version =~ /^2/
   Rabl.register!
 end
