@@ -52,6 +52,7 @@ module Rabl
     attr_accessor :replace_empty_string_values_with_nil_values
     attr_accessor :exclude_nil_values
     attr_accessor :exclude_empty_values_in_collections
+    attr_accessor :camelize_keys
 
     DEFAULT_XML_OPTIONS = { :dasherize  => true, :skip_types => false }
 
@@ -81,6 +82,7 @@ module Rabl
       @replace_empty_string_values_with_nil_values  = false
       @exclude_nil_values                           = false
       @exclude_empty_values_in_collections          = false
+      @camelize_keys                                = false
     end
 
     # @return The JSON engine used to encode Rabl templates into JSON
