@@ -22,16 +22,27 @@ silence_warnings do
   require File.expand_path('../models/user', __FILE__)
 end
 
-Riot.pretty_dots
+if $stdout.tty? then
+  Riot.pretty_dots
+else
+  Riot.dots
+  Riot.plain!
+end
 
-class Riot::Situation
+module RiotTestHelpers
   def char_split(str)
     str.force_encoding("iso-8859-1").split("").sort
   end
+
+  def clean_plist(text)
+    text.gsub(%r{<!DOCTYPE plist PUBLIC \"-//([\w\s]+?)//DTD PLIST 1.0//EN\"}, %q{<!DOCTYPE plist PUBLIC \"-//(TEST)//DTD PLIST 1.0//EN\"})
+  end
+end
+
+class Riot::Situation
+  include RiotTestHelpers
 end
 
 class Riot::Context
-  def char_split(str)
-    str.force_encoding("iso-8859-1").split("").sort
-  end
+  include RiotTestHelpers
 end
